@@ -19,30 +19,6 @@ FiniteDiffM = function(N,d){
   return(Dmat)
 }
 
-# Create an Exponential Smoothing Constraint
-ExpSmMat = function(N,alpha,double=FALSE){
-  alpha = min(alpha,0.99999)
-  alpha = max(alpha,0)
-  k=N:1
-  wt=(1-alpha)^k
-  mat = Matrix::Matrix(0,N,N,sparse=TRUE)
-  mat[1,1]=1
-  for(rw in 2:N){
-    mat[rw,1:(rw-1)] = wt[(N-rw+2):N]
-  }
-  mat = mat/rowSums(mat)
-  
-  if(double){
-    mat = 2*mat-mat%*%mat # double (Browns) exponential smoothing
-    mat[2,1:2] = c(0,1) # don't constrain initial slope
-  }
-  
-  # put in difference form
-  ESM = diag(N)-mat
-  return(ESM)
-}
-
-
 # AR matrix
 ARmat = function(N,ar){
   
@@ -63,8 +39,6 @@ ARmat = function(N,ar){
   return(mat)
 }
 
-
-
 # Create seasonal difference matrix
 Seasonal_DM= function(N,lag=12,sumFirst=TRUE){
   Dm = Matrix::Diagonal(N)
@@ -77,4 +51,18 @@ Seasonal_DM= function(N,lag=12,sumFirst=TRUE){
     Dm[1,1:lag] =1
   }
   return(Dm)
+}
+
+Seasonal_DM_t2= function(N,lag=12){
+  Dm = Matrix::Diagonal(N)
+  if( N <= lag){
+    return(0*Dm)
+  }
+  
+  for(k in 1:(lag-1)){
+    Dm[(row(Dm)==(col(Dm)+k))]=1
+  }
+  
+  Dm[1:(lag-1),1:(lag-1)]=0
+  return(Dm/lag)
 }
\ No newline at end of file
